const PRECACHE = 'precache-v20211217-2';
const RUNTIME = 'runtime-v20211217-2';

// Llista d'arxius que cal desar en memòria cau
const PRECACHE_URLS = [
  'index.html',
  './', // Àlies de index.html
  'js/backbone.js',
  'js/bootstrap.bundle.min.js',
  'js/joint.min.js',
  'js/joint.shapes.org.min.js',
  'js/jquery-3.6.0.js',
  'js/jquery-ui.js',
  'js/lodash.js',
  'js/scripts.js',
  'css/bootstrap-icons.css',
  'css/bootstrap.min.css',
  'css/estils.css',
  'css/joint.core.min.css',
  'css/joint.min.css',
  'css/jquery-ui.css',
  'css/fonts/bootstrap-icons.woff',
  'css/fonts/bootstrap-icons.woff2',
  'images/icons-192.png',
  'images/icons-512.png',
  'JSON/config.json',
  'JSON/conv_DAM.json',
  'JSON/GEI.json'
];

// Instal·lació
self.addEventListener('install', event => {
  event.waitUntil(
    caches.open(PRECACHE)
      .then(cache => cache.addAll(PRECACHE_URLS))
      .then(self.skipWaiting())
  );
});

// Neteja de memòria cau
self.addEventListener('activate', event => {
  const currentCaches = [PRECACHE, RUNTIME];
  event.waitUntil(
    caches.keys().then(cacheNames => {
      return cacheNames.filter(cacheName => !currentCaches.includes(cacheName));
    }).then(cachesToDelete => {
      return Promise.all(cachesToDelete.map(cacheToDelete => {
        return caches.delete(cacheToDelete);
      }));
    }).then(() => self.clients.claim())
  );
});

// Si detecta peticions pròpies, les mostra de memòria cau si les té, i sinó les desa a la memòria cau per a futures peticions.
self.addEventListener('fetch', event => {
  if (event.request.url.startsWith(self.location.origin)) {
    event.respondWith(
      caches.match(event.request).then(cachedResponse => {
        if (cachedResponse) {
          return cachedResponse;
        }

        return caches.open(RUNTIME).then(cache => {
          return fetch(event.request).then(response => {
            // Desat de les crides no emmagatzemades a la memòria cau
            return cache.put(event.request, response.clone()).then(() => {
              return response;
            });
          });
        });
      })
    );
  }
});



/*self.addEventListener('fetch', event =>{
    event.respondWith(async function () {
       var cache = await caches.open(PRECACHE);
       var cachedResponsePromise = await cache.match(event.request);
       var networkResponsePromise = fetch(event.request);
       event.waitUntil(async function () {
          var networkResponse = await networkResponsePromise;
          await cache.put(event.request, networkResponse.clone());
       }());
       return cachedResponsePromise || networkResponsePromise;
     }());
 });*/